@@ -11,6 +11,9 @@ class Settings(BaseSettings):
     hf_token: Optional[str] = None
     ollama_endpoint: str = "http://localhost:11434/api/generate"
     ollama_model: str = "llama2"
+    azure_api_key: Optional[str] = None
+    azure_api_endpoint: Optional[str] = None
+    azure_deployment_id: Optional[str] = None
 
     model_config = SettingsConfigDict(env_file=".env")
 
